@@ -1,5 +1,5 @@
-from helpers.virtual_files import string_to_virtual_repo
-from stack_graphs_python import index, Querier, Language
+from helpers.virtual_files import string_to_virtual_files
+from stack_graphs_python import index, Indexer, Querier, Language
 import os
 
 code = """
@@ -19,10 +19,23 @@ export const foo = "bar"
 """
 
 
-def test_stack_graphs_python():
-    with string_to_virtual_repo(code) as (dir, positions):
-        db_path = os.path.abspath("./db.sqlite")
-        dir = os.path.abspath(dir)
+def test_js_ok():
+    with string_to_virtual_files(code) as (dir, positions):
+        db_path = os.path.join(dir, "db.sqlite")
+        indexer = Indexer(db_path, [Language.JavaScript])
+        indexer.index_all([dir])
+        querier = Querier(db_path)
+        source_reference = positions["query"]
+        results = querier.definitions(source_reference)
+        assert len(results) == 2
+        expected = [positions["ref1"], positions["ref2"]]
+        for i, result in enumerate(results):
+            assert result == expected[i]
+
+
+def test_js_ok_legacy_index():
+    with string_to_virtual_files(code) as (dir, positions):
+        db_path = os.path.join(dir, "db.sqlite")
         index([dir], db_path, language=Language.JavaScript)
         querier = Querier(db_path)
         source_reference = positions["query"]
